@@ -1,4 +1,4 @@
-from pyot.utils import loop_run
+import asyncio
 from pyot.models import riot
 from .__core__ import SyotBaseObject
 
@@ -9,11 +9,11 @@ class SyotBase(SyotBaseObject):
 
 class Account(SyotBase, riot.Account):
     def get(self, **kwargs):
-        return loop_run(super().get(**kwargs))
+        return asyncio.run(super().get(**kwargs))
 
 class ActiveShard(SyotBase, riot.ActiveShard):
     def get(self, **kwargs):
-        return loop_run(super().get(**kwargs))
+        return asyncio.run(super().get(**kwargs))
 
 SyotBase._bridges = {
     "Account": Account,
